@@ -20,6 +20,7 @@ class Paths:
     DISMISS_DIALOGUE = '//button[@class="aOOlW   HoLwm "]'
 
     # NAV TO USER PROCEDURE 
+    WAIT_BEFORE_LOGIN = '//p[contains(text(), "Please wait")]'
     INCORRECT_USERNAME_ALERT = '//p[@role="alert" and @id="slfErrorAlert"]'
     INCORRECT_PASSWORD_ALERT = '//div[@class="piCib"]'
     INCORRECT_PASSWORD_ALERT_BTNS = '{}//button[contains(@class, "aOOlW")]'
@@ -78,7 +79,8 @@ class Paths:
 
     # SCRAPING
     # Scrape Followers Procedure
-    FOLLOWERS_BTN = '//li[@class=" LH36I"]//descendant::a'
+    FOLLOWERS_BTN = '//a[contains(@href, "followers")  and not(contains(@href, "mutual"))]'
+    FOLLOWED_BTN = '//a[contains(@href, "following") and not(contains(@href, "mutual"))]'
     FOLLOWERS_LIST_MAIN = '//main[@role="main"]'
     FOLLOWERS_LIST = '//ul[@class=" jjbaz _6xe7A"]'
     FOLLOWER_USER_DIV = '{}//li'.format(FOLLOWERS_LIST)
@@ -87,6 +89,9 @@ class Paths:
     # Scrape User Posts Procedure
     SHORTCODE_DIV = '//div[@class="v1Nh3 kIKUG  _bz0w"]//descendant::a'
 
+    # EXPLORE PAGE
+    EXPLORE_SEARCH_INPUT = '//input[@class="j_2Hd    iwQA6 RO68f  M5V28"]'
+
     
 
 class ClientUrls:
@@ -102,10 +107,24 @@ class ClientUrls:
     POST_URL = 'https://www.instagram.com/p/{}/'
     COMMENTS_URL = 'https://www.instagram.com/p/{}/comments/'
     EXPLORE_PAGE = 'https://www.instagram.com/explore/'
+    LOCATION_PAGE = 'https://www.instagram.com/explore/locations/{}/{}/'
 
 
 class GraphUrls:
     GRAPH_USER='https://www.instagram.com/{}/?__a=1'
     GRAPH_TAGS='https://www.instagram.com/explore/tags/{}/?__a=1'
     GRAPH_ACTIVITY = 'https://www.instagram.com/accounts/activity/?__a=1'
-    GRAPH_POST = 'https://www.instagram.com/p/{}/?__a=1'
\ No newline at end of file
+    GRAPH_POST = 'https://www.instagram.com/p/{}/?__a=1'
+    GRAPH_SEARCH = 'https://www.instagram.com/web/search/topsearch/?query={}'
+    GRAPH_LOCATION = 'https://www.instagram.com/explore/locations/{}/{}/?__a=1'
+
+    GRAPH_FIRST_FOLLOWERS = 'https://www.instagram.com/graphql/query/?query_hash={QUERY_HASH}&variables=%7B%22id%22%3A%22{ID}%22%2C%22include_reel%22%3Atrue%2C%22fetch_mutual%22%3Atrue%2C%22first%22%3A24%7D'
+    GRAPH_CURSOR_FOLLOWERS = 'https://www.instagram.com/graphql/query/?query_hash={QUERY_HASH}&variables=%7B%22id%22%3A%22{ID}%22%2C%22include_reel%22%3Atrue%2C%22fetch_mutual%22%3Afalse%2C%22first%22%3A12%2C%22after%22%3A%22{END_CURSOR}%3D%3D%22%7D'
+
+    GRAPH_FIRST_FOLLOWING = 'https://www.instagram.com/graphql/query/?query_hash={QUERY_HASH}8&variables=%7B%22id%22%3A%22{ID}%22%2C%22include_reel%22%3Atrue%2C%22fetch_mutual%22%3Afalse%2C%22first%22%3A24%7D'
+    GRAPH_CURSOR_FOLLOWING = 'https://www.instagram.com/graphql/query/?query_hash={QUERY_HASH}8&variables=%7B%22id%22%3A%22{ID}%22%2C%22include_reel%22%3Atrue%2C%22fetch_mutual%22%3Afalse%2C%22first%22%3A12%2C%22after%22%3A%22{END_CURSOR}%3D%3D%22%7D'
+
+
+class QueryHashes:
+    FOLLOWERS_HASH = '5aefa9893005572d237da5068082d8d5'
+    FOLLOWING_HASH = '3dec7e2c57367ef3da3d987d89f9dbc'
\ No newline at end of file
